<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;

class BaseController extends Controller
{
    protected function uploadImagem(Request $request, $campo, $pasta, $imagemAntiga = null)
    {
        if ($request->hasFile($campo)) {
            if ($imagemAntiga) {
                Storage::delete($imagemAntiga);
            }

            $arquivo = $request->file($campo);
            $nome = time() . '_' . $arquivo->getClientOriginalName();
            return $arquivo->storeAs($pasta, $nome, 'public');
        }

        return $imagemAntiga;
    }

    protected function excluirImagem($caminho)
    {
        if ($caminho) {
            Storage::delete($caminho);
        }
    }

    protected function validarDados(Request $request, array $regras)
    {
        return $request->validate($regras, [
            'required' => 'O campo :attribute é obrigatório.',
            'email' => 'O campo :attribute deve ser um e-mail válido.',
            'unique' => 'O valor informado para o campo :attribute já está em uso.',
            'min' => 'O campo :attribute deve ter no mínimo :min caracteres.',
            'max' => 'O campo :attribute deve ter no máximo :max caracteres.',
            'image' => 'O arquivo :attribute deve ser uma imagem.',
            'mimes' => 'O arquivo :attribute deve ser do tipo: :values.',
            'max' => 'O arquivo :attribute não pode ter mais que :max kilobytes.',
        ]);
    }

    protected function retornarSucesso($mensagem, $rota = null)
    {
        if ($rota) {
            return redirect()->route($rota)->with('success', $mensagem);
        }
        return back()->with('success', $mensagem);
    }

    protected function retornarErro($mensagem)
    {
        return back()->with('error', $mensagem);
    }
} 