<?php

namespace App\Http\Controllers\Admin;

use App\Models\Cliente;
use Illuminate\Http\Request;

class ClienteController extends BaseController
{
    public function index()
    {
        $clientes = Cliente::orderBy('ordem')->paginate(10);
        return view('admin.clientes.index', compact('clientes'));
    }

    public function create()
    {
        return view('admin.clientes.create');
    }

    public function store(Request $request)
    {
        $dados = $this->validarDados($request, [
            'nome' => 'required|min:3|max:255',
            'logo' => 'required|image|mimes:jpeg,png,jpg|max:2048',
            'website' => 'nullable|url|max:255',
            'ordem' => 'required|integer|min:0',
            'ativo' => 'boolean'
        ]);

        $dados['ativo'] = $request->has('ativo');
        $dados['logo'] = $this->uploadImagem($request, 'logo', 'clientes');

        Cliente::create($dados);

        return $this->retornarSucesso('Cliente criado com sucesso!', 'admin.clientes.index');
    }

    public function edit(Cliente $cliente)
    {
        return view('admin.clientes.edit', compact('cliente'));
    }

    public function update(Request $request, Cliente $cliente)
    {
        $dados = $this->validarDados($request, [
            'nome' => 'required|min:3|max:255',
            'logo' => 'nullable|image|mimes:jpeg,png,jpg|max:2048',
            'website' => 'nullable|url|max:255',
            'ordem' => 'required|integer|min:0',
            'ativo' => 'boolean'
        ]);

        $dados['ativo'] = $request->has('ativo');
        $dados['logo'] = $this->uploadImagem($request, 'logo', 'clientes', $cliente->logo);

        $cliente->update($dados);

        return $this->retornarSucesso('Cliente atualizado com sucesso!', 'admin.clientes.index');
    }

    public function destroy(Cliente $cliente)
    {
        $this->excluirImagem($cliente->logo);
        $cliente->delete();

        return $this->retornarSucesso('Cliente excluído com sucesso!', 'admin.clientes.index');
    }
} 