<?php

namespace App\Http\Controllers\Admin;

use App\Models\Postagem;
use Illuminate\Http\Request;

class PostagemController extends BaseController
{
    public function index()
    {
        $postagens = Postagem::with('user')->latest()->paginate(10);
        return view('admin.postagens.index', compact('postagens'));
    }

    public function create()
    {
        return view('admin.postagens.create');
    }

    public function store(Request $request)
    {
        $dados = $this->validarDados($request, [
            'titulo' => 'required|min:3|max:255',
            'resumo' => 'required|min:10|max:255',
            'conteudo' => 'required|min:50',
            'imagem' => 'nullable|image|mimes:jpeg,png,jpg|max:2048'
        ]);

        $dados['user_id'] = auth()->id();
        $dados['imagem'] = $this->uploadImagem($request, 'imagem', 'postagens');

        Postagem::create($dados);

        return $this->retornarSucesso('Postagem criada com sucesso!', 'admin.postagens.index');
    }

    public function edit(Postagem $postagem)
    {
        return view('admin.postagens.edit', compact('postagem'));
    }

    public function update(Request $request, Postagem $postagem)
    {
        $dados = $this->validarDados($request, [
            'titulo' => 'required|min:3|max:255',
            'resumo' => 'required|min:10|max:255',
            'conteudo' => 'required|min:50',
            'imagem' => 'nullable|image|mimes:jpeg,png,jpg|max:2048'
        ]);

        $dados['imagem'] = $this->uploadImagem($request, 'imagem', 'postagens', $postagem->imagem);

        $postagem->update($dados);

        return $this->retornarSucesso('Postagem atualizada com sucesso!', 'admin.postagens.index');
    }

    public function destroy(Postagem $postagem)
    {
        $this->excluirImagem($postagem->imagem);
        $postagem->delete();

        return $this->retornarSucesso('Postagem excluída com sucesso!', 'admin.postagens.index');
    }
} 