<?php

namespace App\Http\Controllers\Admin;

use App\Models\Servico;
use Illuminate\Http\Request;

class ServicoController extends BaseController
{
    public function index()
    {
        $servicos = Servico::orderBy('ordem')->paginate(10);
        return view('admin.servicos.index', compact('servicos'));
    }

    public function create()
    {
        return view('admin.servicos.create');
    }

    public function store(Request $request)
    {
        $dados = $this->validarDados($request, [
            'titulo' => 'required|min:3|max:255',
            'descricao' => 'required|min:10',
            'icone' => 'required|min:3|max:50',
            'ordem' => 'required|integer|min:0',
            'ativo' => 'boolean',
            'imagem' => 'nullable|image|mimes:jpeg,png,jpg|max:2048'
        ]);

        $dados['ativo'] = $request->has('ativo');
        $dados['imagem'] = $this->uploadImagem($request, 'imagem', 'servicos');

        Servico::create($dados);

        return $this->retornarSucesso('Serviço criado com sucesso!', 'admin.servicos.index');
    }

    public function edit(Servico $servico)
    {
        return view('admin.servicos.edit', compact('servico'));
    }

    public function update(Request $request, Servico $servico)
    {
        $dados = $this->validarDados($request, [
            'titulo' => 'required|min:3|max:255',
            'descricao' => 'required|min:10',
            'icone' => 'required|min:3|max:50',
            'ordem' => 'required|integer|min:0',
            'ativo' => 'boolean',
            'imagem' => 'nullable|image|mimes:jpeg,png,jpg|max:2048'
        ]);

        $dados['ativo'] = $request->has('ativo');
        $dados['imagem'] = $this->uploadImagem($request, 'imagem', 'servicos', $servico->imagem);

        $servico->update($dados);

        return $this->retornarSucesso('Serviço atualizado com sucesso!', 'admin.servicos.index');
    }

    public function destroy(Servico $servico)
    {
        $this->excluirImagem($servico->imagem);
        $servico->delete();

        return $this->retornarSucesso('Serviço excluído com sucesso!', 'admin.servicos.index');
    }
} 