<?php

namespace App\Http\Controllers;

use App\Models\Servico;
use App\Models\Depoimento;
use App\Models\Postagem;
use App\Models\Contato;
use App\Models\Cliente;
use App\Models\Faq;
use Illuminate\Http\Request;

class SiteController extends Controller
{
    public function index()
    {
        $servicos = Servico::ativos()->take(6)->get();
        $depoimentos = Depoimento::ativos()->take(3)->get();
        $postagens = Postagem::publicadas()->take(3)->get();
        $clientes = Cliente::all();
        $faqs = Faq::all();

        return view('site.index', compact('servicos', 'depoimentos', 'postagens', 'clientes', 'faqs'));
    }

    public function sobre()
    {
        return view('site.sobre');
    }

    public function servicos()
    {
        $servicos = Servico::ativos()->get();
        return view('site.servicos', compact('servicos'));
    }

    public function blog()
    {
        $postagens = Postagem::publicadas()->paginate(9);
        return view('site.blog', compact('postagens'));
    }

    public function postagem($slug)
    {
        $postagem = Postagem::where('slug', $slug)->publicadas()->firstOrFail();
        return view('site.postagem', compact('postagem'));
    }

    public function contato()
    {
        return view('site.contato');
    }

    public function enviarContato(Request $request)
    {
        $validado = $request->validate([
            'nome' => 'required|min:3',
            'email' => 'required|email',
            'telefone' => 'nullable',
            'empresa' => 'nullable',
            'mensagem' => 'required|min:10'
        ]);

        Contato::create($validado);

        return redirect()
            ->route('site.contato')
            ->with('sucesso', 'Mensagem enviada com sucesso! Em breve entraremos em contato.');
    }
} 