<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Contato extends Model
{
    use HasFactory;

    protected $table = 'contatos';
    protected $fillable = [
        'nome',
        'email',
        'telefone',
        'empresa',
        'mensagem',
        'status'
    ];

    // Lista de status possíveis
    public const STATUS = [
        'novo' => 'Novo',
        'em_andamento' => 'Em Andamento',
        'respondido' => 'Respondido',
        'arquivado' => 'Arquivado'
    ];

    // Retorna o status formatado
    public function getStatusFormatadoAttribute()
    {
        return self::STATUS[$this->status] ?? $this->status;
    }

    // Escopo para contatos não arquivados
    public function scopeAtivos($query)
    {
        return $query->where('status', '!=', 'arquivado')->orderByDesc('created_at');
    }
} 