<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Str;

class Postagem extends Model
{
    use HasFactory;
    
    protected $table = 'postagens';

    protected $fillable = [
        'titulo',
        'slug',
        'resumo',
        'conteudo',
        'imagem',
        'user_id',
        'ativo',
        'publicado_em'
    ];

    protected $casts = [
        'ativo' => 'boolean',
        'publicado_em' => 'datetime'
    ];

    // Relacionamento com o autor da postagem
    public function autor()
    {
        return $this->belongsTo(User::class, 'user_id');
    }

    // Gera o slug automaticamente antes de salvar
    protected static function boot()
    {
        parent::boot();
        
        static::creating(function ($postagem) {
            if (empty($postagem->slug)) {
                $postagem->slug = Str::slug($postagem->titulo);
            }
        });
    }

    // Escopo para postagens ativas e publicadas
    public function scopePublicadas($query)
    {
        return $query->where('ativo', true)
                    ->whereNotNull('publicado_em')
                    ->where('publicado_em', '<=', now())
                    ->orderByDesc('publicado_em');
    }

    // Retorna a URL da imagem com fallback
    public function getImagemUrlAttribute()
    {
        return $this->imagem 
            ? asset('storage/' . $this->imagem)
            : asset('images/default-post.jpg');
    }

    // Retorna um resumo do conteúdo
    public function getResumoAttribute($value)
    {
        return $value ?: Str::limit(strip_tags($this->conteudo), 200);
    }
} 