<?php

namespace Database\Seeders;

use Illuminate\Database\Seeder;
use App\Models\Postagem;
use App\Models\User;

class PostagemSeeder extends Seeder
{
    public function run()
    {
        $user = User::first();

        $postagens = [
            [
                'titulo' => 'Como escolher o melhor sistema PDV para seu negócio',
                'resumo' => 'Dicas e considerações importantes para escolher o sistema de ponto de venda ideal para sua empresa.',
                'conteudo' => '<p>Escolher o sistema PDV ideal para seu negócio é uma decisão crucial que pode impactar diretamente a eficiência e o sucesso da sua operação. Aqui estão alguns pontos importantes a considerar:</p>

<h3>1. Tamanho do Negócio</h3>
<p>O primeiro passo é avaliar o tamanho do seu negócio. Sistemas mais simples podem ser suficientes para pequenas lojas, enquanto empresas maiores podem precisar de soluções mais robustas.</p>

<h3>2. Funcionalidades Essenciais</h3>
<p>Identifique as funcionalidades essenciais para seu negócio:</p>
<ul>
    <li>Controle de estoque</li>
    <li>Gestão de clientes</li>
    <li>Relatórios gerenciais</li>
    <li>Integração com TEF</li>
</ul>

<h3>3. Facilidade de Uso</h3>
<p>Um sistema intuitivo e fácil de usar é fundamental para garantir a produtividade da equipe e reduzir erros operacionais.</p>

<h3>4. Suporte e Treinamento</h3>
<p>Verifique se o fornecedor oferece suporte técnico adequado e treinamento para sua equipe.</p>

<h3>5. Custo-Benefício</h3>
<p>Analise o investimento necessário em relação aos benefícios oferecidos pelo sistema.</p>',
                'imagem' => 'blog/pdv.jpg',
                'publicado_em' => now()
            ],
            [
                'titulo' => '5 benefícios da automação comercial para pequenos negócios',
                'resumo' => 'Descubra como a automação comercial pode transformar e impulsionar seu pequeno negócio.',
                'conteudo' => '<p>A automação comercial não é mais um recurso exclusivo para grandes empresas. Pequenos negócios também podem se beneficiar significativamente dessas soluções. Confira os principais benefícios:</p>

<h3>1. Redução de Erros</h3>
<p>A automação minimiza erros manuais em processos como:</p>
<ul>
    <li>Controle de estoque</li>
    <li>Gestão financeira</li>
    <li>Emissão de documentos fiscais</li>
</ul>

<h3>2. Aumento da Produtividade</h3>
<p>Processos automatizados permitem que sua equipe foque em atividades mais estratégicas e no atendimento ao cliente.</p>

<h3>3. Melhor Gestão Financeira</h3>
<p>Controle mais preciso de:</p>
<ul>
    <li>Entradas e saídas</li>
    <li>Fluxo de caixa</li>
    <li>Relatórios financeiros</li>
</ul>

<h3>4. Tomada de Decisão</h3>
<p>Dados precisos e em tempo real ajudam na tomada de decisões mais assertivas.</p>

<h3>5. Experiência do Cliente</h3>
<p>Processos mais ágeis e precisos resultam em um atendimento mais eficiente e satisfatório.</p>',
                'imagem' => 'blog/automacao.jpg',
                'publicado_em' => now()->subDays(2)
            ],
            [
                'titulo' => 'Dicas para otimizar o controle de estoque',
                'resumo' => 'Aprenda estratégias eficientes para gerenciar seu estoque e evitar perdas.',
                'conteudo' => '<p>Um controle de estoque eficiente é fundamental para o sucesso de qualquer negócio. Confira algumas dicas importantes:</p>

<h3>1. Inventário Regular</h3>
<p>Realize contagens físicas periodicamente para garantir a precisão dos dados do sistema.</p>

<h3>2. Estabeleça Níveis Mínimos</h3>
<p>Defina pontos de reordenação para cada produto, evitando rupturas de estoque.</p>

<h3>3. Organização do Estoque</h3>
<p>Mantenha uma organização lógica dos produtos, facilitando a localização e controle.</p>

<h3>4. Gestão de Fornecedores</h3>
<p>Mantenha bons relacionamentos com fornecedores e tenha alternativas para produtos críticos.</p>

<h3>5. Análise de Dados</h3>
<p>Utilize relatórios e indicadores para:</p>
<ul>
    <li>Identificar produtos mais vendidos</li>
    <li>Detectar produtos com baixa rotatividade</li>
    <li>Otimizar compras</li>
</ul>',
                'imagem' => 'blog/estoque.jpg',
                'publicado_em' => now()->subDays(4)
            ]
        ];

        foreach ($postagens as $postagem) {
            $postagem['user_id'] = $user->id;
            Postagem::create($postagem);
        }
    }
} 