@extends('layouts.admin')

@section('titulo', isset($postagem) ? 'Editar Postagem' : 'Nova Postagem')

@section('conteudo')
<div class="container-fluid">
    <div class="d-flex justify-content-between align-items-center mb-4">
        <h1 class="h3 mb-0">{{ isset($postagem) ? 'Editar Postagem' : 'Nova Postagem' }}</h1>
        <a href="{{ route('admin.postagens.index') }}" class="btn btn-secondary">
            <i class="fas fa-arrow-left"></i> Voltar
        </a>
    </div>

    <div class="card">
        <div class="card-body">
            <form action="{{ isset($postagem) ? route('admin.postagens.update', $postagem) : route('admin.postagens.store') }}" method="POST" enctype="multipart/form-data">
                @csrf
                @if(isset($postagem))
                    @method('PUT')
                @endif

                <div class="row">
                    <div class="col-md-8">
                        <div class="mb-3">
                            <label for="titulo" class="form-label">Título</label>
                            <input type="text" class="form-control @error('titulo') is-invalid @enderror" id="titulo" name="titulo" value="{{ old('titulo', $postagem->titulo ?? '') }}" required>
                            @error('titulo')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>

                        <div class="mb-3">
                            <label for="resumo" class="form-label">Resumo</label>
                            <textarea class="form-control @error('resumo') is-invalid @enderror" id="resumo" name="resumo" rows="3" required>{{ old('resumo', $postagem->resumo ?? '') }}</textarea>
                            @error('resumo')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>

                        <div class="mb-3">
                            <label for="conteudo" class="form-label">Conteúdo</label>
                            <textarea class="form-control @error('conteudo') is-invalid @enderror" id="conteudo" name="conteudo" rows="10" required>{{ old('conteudo', $postagem->conteudo ?? '') }}</textarea>
                            @error('conteudo')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                    </div>

                    <div class="col-md-4">
                        <div class="mb-3">
                            <label for="imagem" class="form-label">Imagem</label>
                            <input type="file" class="form-control @error('imagem') is-invalid @enderror" id="imagem" name="imagem" accept="image/*">
                            @error('imagem')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                            @if(isset($postagem) && $postagem->imagem)
                                <div class="mt-2">
                                    <img src="{{ asset('storage/' . $postagem->imagem) }}" alt="{{ $postagem->titulo }}" class="img-thumbnail" style="max-width: 100%;">
                                </div>
                            @endif
                        </div>
                    </div>
                </div>

                <div class="text-end">
                    <button type="submit" class="btn btn-primary">
                        <i class="fas fa-save"></i> Salvar
                    </button>
                </div>
            </form>
        </div>
    </div>
</div>

@push('scripts')
<script src="https://cdn.ckeditor.com/ckeditor5/27.1.0/classic/ckeditor.js"></script>
<script>
    ClassicEditor
        .create(document.querySelector('#conteudo'))
        .catch(error => {
            console.error(error);
        });
</script>
@endpush
@endsection 