@extends('layouts.admin')

@section('titulo', 'Postagens')

@section('conteudo')
<div class="container-fluid">
    <div class="d-flex justify-content-between align-items-center mb-4">
        <h1 class="h3 mb-0">Postagens</h1>
        <a href="{{ route('admin.postagens.create') }}" class="btn btn-primary">
            <i class="fas fa-plus"></i> Nova Postagem
        </a>
    </div>

    <div class="card">
        <div class="card-body">
            <div class="table-responsive">
                <table class="table table-hover">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>Imagem</th>
                            <th>Título</th>
                            <th>Autor</th>
                            <th>Data</th>
                            <th>Ações</th>
                        </tr>
                    </thead>
                    <tbody>
                        @forelse($postagens as $postagem)
                            <tr>
                                <td>{{ $postagem->id }}</td>
                                <td>
                                    @if($postagem->imagem)
                                        <img src="{{ asset('storage/' . $postagem->imagem) }}" alt="{{ $postagem->titulo }}" class="img-thumbnail" style="max-width: 50px;">
                                    @else
                                        <span class="text-muted">Sem imagem</span>
                                    @endif
                                </td>
                                <td>{{ $postagem->titulo }}</td>
                                <td>{{ $postagem->user->name }}</td>
                                <td>{{ $postagem->created_at->format('d/m/Y H:i') }}</td>
                                <td>
                                    <div class="btn-group">
                                        <a href="{{ route('admin.postagens.edit', $postagem) }}" class="btn btn-sm btn-info" title="Editar">
                                            <i class="fas fa-edit"></i>
                                        </a>
                                        <form action="{{ route('admin.postagens.destroy', $postagem) }}" method="POST" class="d-inline">
                                            @csrf
                                            @method('DELETE')
                                            <button type="submit" class="btn btn-sm btn-danger" title="Excluir" onclick="return confirm('Tem certeza que deseja excluir esta postagem?')">
                                                <i class="fas fa-trash"></i>
                                            </button>
                                        </form>
                                    </div>
                                </td>
                            </tr>
                        @empty
                            <tr>
                                <td colspan="6" class="text-center">Nenhuma postagem encontrada.</td>
                            </tr>
                        @endforelse
                    </tbody>
                </table>
            </div>

            <div class="mt-4">
                {{ $postagens->links() }}
            </div>
        </div>
    </div>
</div>
@endsection 