@extends('layouts.site')

@section('titulo', 'Contato')

@section('conteudo')
<!-- Hero Section -->
<section class="hero-section py-5">
    <div class="container">
        <div class="row align-items-center min-vh-50">
            <div class="col-lg-6 fade-in" data-aos="fade-right">
                <h1 class="display-4 text-white mb-4 fw-bold">Entre em Contato</h1>
                <p class="lead text-white-50 mb-4">Estamos prontos para atender você e transformar seu negócio</p>
            </div>
            <div class="col-lg-6 fade-in" data-aos="fade-left">
                <img src="{{ asset('images/contact-hero.jpg') }}" alt="Contato" class="img-fluid rounded-3 shadow">
            </div>
        </div>
    </div>
</section>

<!-- Informações de Contato -->
<section class="py-5">
    <div class="container">
        <div class="row g-4">
            <div class="col-md-4 fade-in" data-aos="fade-up">
                <div class="card h-100">
                    <div class="card-body p-4 text-center">
                        <div class="feature-icon mb-4">
                            <i class="fas fa-map-marker-alt fa-2x"></i>
                        </div>
                        <h3 class="h5 fw-bold">Endereço</h3>
                        <p class="text-muted mb-0">Rua das Flores, 123<br>Centro - São Paulo/SP</p>
                    </div>
                </div>
            </div>
            
            <div class="col-md-4 fade-in" data-aos="fade-up" data-aos-delay="100">
                <div class="card h-100">
                    <div class="card-body p-4 text-center">
                        <div class="feature-icon mb-4">
                            <i class="fas fa-phone fa-2x"></i>
                        </div>
                        <h3 class="h5 fw-bold">Telefone</h3>
                        <p class="text-muted mb-0">(11) 1234-5678<br>(11) 98765-4321</p>
                    </div>
                </div>
            </div>
            
            <div class="col-md-4 fade-in" data-aos="fade-up" data-aos-delay="200">
                <div class="card h-100">
                    <div class="card-body p-4 text-center">
                        <div class="feature-icon mb-4">
                            <i class="fas fa-envelope fa-2x"></i>
                        </div>
                        <h3 class="h5 fw-bold">E-mail</h3>
                        <p class="text-muted mb-0">contato@smartuniverse.com.br<br>suporte@smartuniverse.com.br</p>
                    </div>
                </div>
            </div>
        </div>
    </div>
</section>

<!-- Formulário de Contato -->
<section class="py-5 bg-light">
    <div class="container">
        <div class="row justify-content-center">
            <div class="col-lg-8 fade-in" data-aos="fade-up">
                <div class="card shadow-sm">
                    <div class="card-body p-5">
                        <h2 class="text-center mb-4">Envie sua Mensagem</h2>
                        
                        @if(session('success'))
                        <div class="alert alert-success alert-dismissible fade show" role="alert">
                            {{ session('success') }}
                            <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
                        </div>
                        @endif

                        <form action="{{ route('site.contato.enviar') }}" method="POST">
                            @csrf
                            <div class="row g-3">
                                <div class="col-md-6">
                                    <label for="nome" class="form-label">Nome</label>
                                    <input type="text" class="form-control @error('nome') is-invalid @enderror" 
                                           id="nome" name="nome" value="{{ old('nome') }}" required>
                                    @error('nome')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                <div class="col-md-6">
                                    <label for="email" class="form-label">E-mail</label>
                                    <input type="email" class="form-control @error('email') is-invalid @enderror" 
                                           id="email" name="email" value="{{ old('email') }}" required>
                                    @error('email')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                <div class="col-md-6">
                                    <label for="telefone" class="form-label">Telefone</label>
                                    <input type="tel" class="form-control @error('telefone') is-invalid @enderror" 
                                           id="telefone" name="telefone" value="{{ old('telefone') }}">
                                    @error('telefone')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                <div class="col-md-6">
                                    <label for="assunto" class="form-label">Assunto</label>
                                    <select class="form-select @error('assunto') is-invalid @enderror" 
                                            id="assunto" name="assunto" required>
                                        <option value="">Selecione um assunto</option>
                                        <option value="orcamento" {{ old('assunto') == 'orcamento' ? 'selected' : '' }}>Orçamento</option>
                                        <option value="suporte" {{ old('assunto') == 'suporte' ? 'selected' : '' }}>Suporte</option>
                                        <option value="parceria" {{ old('assunto') == 'parceria' ? 'selected' : '' }}>Parceria</option>
                                        <option value="outro" {{ old('assunto') == 'outro' ? 'selected' : '' }}>Outro</option>
                                    </select>
                                    @error('assunto')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                <div class="col-12">
                                    <label for="mensagem" class="form-label">Mensagem</label>
                                    <textarea class="form-control @error('mensagem') is-invalid @enderror" 
                                              id="mensagem" name="mensagem" rows="5" required>{{ old('mensagem') }}</textarea>
                                    @error('mensagem')
                                    <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                <div class="col-12 text-center">
                                    <button type="submit" class="btn btn-modern btn-lg">Enviar Mensagem</button>
                                </div>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
</section>

<!-- Mapa -->
<section class="py-5">
    <div class="container">
        <div class="row justify-content-center">
            <div class="col-lg-10 fade-in" data-aos="fade-up">
                <div class="ratio ratio-21x9">
                    <iframe src="https://www.google.com/maps/embed?pb=!1m18!1m12!1m3!1d3657.197577494987!2d-46.6522771!3d-23.5505199!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!3m3!1m2!1s0x0%3A0x0!2zMjPCsDMzJzAxLjkiUyA0NsKwMzknMDguMiJX!5e0!3m2!1spt-BR!2sbr!4v1625761234567!5m2!1spt-BR!2sbr" 
                            width="100%" 
                            height="450" 
                            style="border:0;" 
                            allowfullscreen="" 
                            loading="lazy">
                    </iframe>
                </div>
            </div>
        </div>
    </div>
</section>
@endsection 