@extends('layouts.site')

@section('conteudo')
    <!-- Hero Section -->
    <section class="hero-section py-4 bg-gradient-primary text-white">
        <div class="container">
            <div class="row justify-content-center">
                <div class="col-lg-8 text-center">
                    <h1 class="display-4 fw-bold mb-3">Perguntas Frequentes</h1>
                    <p class="lead mb-0">Encontre respostas para as dúvidas mais comuns sobre nossos produtos e serviços.</p>
                </div>
            </div>
        </div>
    </section>

    <!-- FAQ Section -->
    <section class="faq-section py-5">
        <div class="container">
            <!-- Busca e Filtros -->
            <div class="row mb-5">
                <div class="col-lg-8 mx-auto">
                    <div class="search-container bg-white p-4 rounded-4 shadow-sm">
                        <form action="{{ route('site.faq') }}" method="GET" class="search-form">
                            <div class="input-group input-group-lg">
                                <span class="input-group-text bg-transparent border-0">
                                    <i class="fas fa-search text-primary"></i>
                                </span>
                                <input type="text" 
                                       name="busca" 
                                       class="form-control border-0" 
                                       placeholder="Buscar nas perguntas..."
                                       value="{{ request('busca') }}">
                                <button class="btn btn-primary px-4" type="submit">
                                    Buscar
                                </button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>

            <!-- Categorias -->
            <div class="row mb-4">
                <div class="col-12">
                    <div class="d-flex justify-content-center gap-3 flex-wrap">
                        <form action="{{ route('site.faq') }}" method="GET" class="filter-form">
                            <button type="submit" name="categoria" value="" 
                                    class="btn btn-outline-primary {{ !request('categoria') ? 'active' : '' }}">
                                Todas
                            </button>
                        </form>
                        @foreach($categorias as $categoria)
                            <form action="{{ route('site.faq') }}" method="GET" class="filter-form">
                                <button type="submit" name="categoria" value="{{ $categoria }}"
                                        class="btn btn-outline-primary {{ request('categoria') == $categoria ? 'active' : '' }}">
                                    {{ $categoria }}
                                </button>
                            </form>
                        @endforeach
                    </div>
                </div>
            </div>

            <!-- Lista de FAQs -->
            <div class="row">
                <div class="col-lg-8 mx-auto">
                    <div class="accordion" id="faqAccordion">
                        @foreach($faqs as $index => $faq)
                            <div class="accordion-item border-0 mb-3">
                                <h2 class="accordion-header">
                                    <button class="accordion-button {{ $index !== 0 ? 'collapsed' : '' }}" 
                                            type="button" 
                                            data-bs-toggle="collapse" 
                                            data-bs-target="#collapse{{ $faq->id }}">
                                        <i class="fas fa-question-circle text-primary me-2"></i>
                                        {{ $faq->pergunta }}
                                    </button>
                                </h2>
                                <div id="collapse{{ $faq->id }}" 
                                     class="accordion-collapse collapse {{ $index === 0 ? 'show' : '' }}" 
                                     data-bs-parent="#faqAccordion">
                                    <div class="accordion-body">
                                        <div class="d-flex align-items-start">
                                            <i class="fas fa-check-circle text-success me-3 mt-1"></i>
                                            <div>{!! nl2br(e($faq->resposta)) !!}</div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        @endforeach
                    </div>

                    @if($faqs->isEmpty())
                        <div class="text-center py-5">
                            <div class="empty-state mb-4">
                                <i class="fas fa-search fa-3x text-primary mb-3"></i>
                                <h3 class="h4 mb-3">Nenhuma pergunta encontrada</h3>
                                <p class="text-muted mb-4">Tente ajustar sua busca ou filtrar por outra categoria.</p>
                                <a href="{{ route('site.faq') }}" class="btn btn-primary">
                                    <i class="fas fa-redo me-2"></i>Limpar Filtros
                                </a>
                            </div>
                        </div>
                    @endif
                </div>
            </div>
        </div>
    </section>

    <!-- CTA Section -->
    <section class="cta-section py-5 bg-light">
        <div class="container">
            <div class="row justify-content-center">
                <div class="col-lg-8 text-center">
                    <div class="cta-content p-5 rounded-4 bg-white shadow-sm">
                        <h2 class="h3 mb-4">Ainda tem dúvidas?</h2>
                        <p class="lead mb-4">Entre em contato conosco e teremos prazer em ajudar.</p>
                        <a href="{{ route('site.contato') }}" class="btn btn-primary btn-lg">
                            <i class="fas fa-envelope me-2"></i>Fale Conosco
                        </a>
                    </div>
                </div>
            </div>
        </div>
    </section>
@endsection

@push('styles')
<style>
    .bg-gradient-primary {
        background: linear-gradient(135deg, var(--primary-color) 0%, var(--secondary-color) 100%);
    }

    .search-container {
        transition: all 0.3s ease;
    }

    .search-container:hover {
        transform: translateY(-2px);
        box-shadow: 0 5px 15px rgba(0,0,0,0.1) !important;
    }

    .search-form .input-group {
        box-shadow: 0 2px 10px rgba(0,0,0,0.05);
        border-radius: 15px;
        overflow: hidden;
    }

    .search-form input {
        border: none;
        padding: 15px 20px;
    }

    .search-form .btn {
        border-radius: 0 15px 15px 0;
    }

    .btn-outline-primary {
        border-radius: 20px;
        padding: 8px 20px;
        transition: all 0.3s ease;
    }

    .btn-outline-primary:hover,
    .btn-outline-primary.active {
        background-color: var(--primary-color);
        color: white;
        transform: translateY(-2px);
    }

    .accordion-item {
        background: white;
        border-radius: 15px !important;
        overflow: hidden;
        box-shadow: 0 2px 10px rgba(0,0,0,0.05);
        transition: all 0.3s ease;
    }

    .accordion-item:hover {
        transform: translateY(-2px);
        box-shadow: 0 5px 15px rgba(0,0,0,0.1);
    }

    .accordion-button {
        padding: 20px;
        font-weight: 600;
        color: var(--primary-color);
        background-color: white;
    }

    .accordion-button:not(.collapsed) {
        background-color: var(--primary-color);
        color: white;
    }

    .accordion-button:focus {
        box-shadow: none;
    }

    .accordion-body {
        padding: 20px;
        line-height: 1.8;
        background-color: #f8f9fa;
    }

    .empty-state {
        padding: 40px;
        background: white;
        border-radius: 15px;
        box-shadow: 0 2px 10px rgba(0,0,0,0.05);
    }

    .cta-content {
        transition: all 0.3s ease;
    }

    .cta-content:hover {
        transform: translateY(-5px);
        box-shadow: 0 10px 30px rgba(0,0,0,0.1);
    }
</style>
@endpush

@push('scripts')
<script>
    // Scroll suave para a seção de FAQ quando houver busca
    document.addEventListener('DOMContentLoaded', function() {
        if (window.location.search.includes('busca=') || window.location.search.includes('categoria=')) {
            document.querySelector('.faq-section').scrollIntoView({ behavior: 'smooth' });
        }
    });
</script>
@endpush 