<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\SiteController;
use App\Http\Controllers\ServicoController;
use App\Http\Controllers\DepoimentoController;
use App\Http\Controllers\PostagemController;
use App\Http\Controllers\ContatoController;
use App\Http\Controllers\Site\ServicosController;
use App\Http\Controllers\Site\ContatoController as SiteContatoController;
use App\Http\Controllers\Site\FaqController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
*/

// Rotas do Site
Route::get('/', [SiteController::class, 'index'])->name('site.index');
Route::get('/sobre', [SiteController::class, 'sobre'])->name('site.sobre');
Route::get('/servicos', [App\Http\Controllers\Site\ServicosController::class, 'index'])->name('site.servicos');
Route::get('/blog', [SiteController::class, 'blog'])->name('site.blog');
Route::get('/blog/{slug}', [SiteController::class, 'postagem'])->name('site.postagem');
Route::get('/contato', [App\Http\Controllers\Site\ContatoController::class, 'index'])->name('site.contato');
Route::post('/contato/enviar', [App\Http\Controllers\Site\ContatoController::class, 'enviar'])->name('site.contato.enviar');
Route::get('/faq', [FaqController::class, 'index'])->name('site.faq');

// Área Administrativa
Route::middleware(['auth'])->prefix('admin')->group(function () {
    Route::get('/', function () {
        return view('admin.dashboard');
    })->name('admin.dashboard');

    // Rotas de Serviços
    Route::resource('servicos', ServicoController::class);
    
    // Rotas de Depoimentos
    Route::resource('depoimentos', DepoimentoController::class);
    
    // Rotas de Postagens
    Route::resource('postagens', PostagemController::class);
    
    // Rotas de Contatos
    Route::resource('contatos', ContatoController::class)->except(['create', 'store']);
});

// Rotas Administrativas
Route::prefix('admin')->name('admin.')->group(function () {
    // Login
    Route::get('login', [App\Http\Controllers\Admin\AuthController::class, 'showLoginForm'])->name('login');
    Route::post('login', [App\Http\Controllers\Admin\AuthController::class, 'login']);
    Route::post('logout', [App\Http\Controllers\Admin\AuthController::class, 'logout'])->name('logout');

    // Rotas Protegidas
    Route::middleware(['admin'])->group(function () {
        // Dashboard
        Route::get('/', [App\Http\Controllers\Admin\DashboardController::class, 'index'])->name('dashboard');

        // Usuários
        Route::resource('usuarios', App\Http\Controllers\Admin\UsuarioController::class);

        // Postagens
        Route::resource('postagens', App\Http\Controllers\Admin\PostagemController::class);

        // Serviços
        Route::resource('servicos', App\Http\Controllers\Admin\ServicoController::class);

        // Clientes
        Route::resource('clientes', App\Http\Controllers\Admin\ClienteController::class);

        // FAQs
        Route::resource('faqs', App\Http\Controllers\Admin\FaqController::class);

        // Configurações
        Route::get('configuracoes', [App\Http\Controllers\Admin\ConfiguracaoController::class, 'index'])->name('configuracoes');
        Route::put('configuracoes', [App\Http\Controllers\Admin\ConfiguracaoController::class, 'update']);
    });
});

Route::middleware(['auth', 'admin'])->prefix('admin')->name('admin.')->group(function () {
    Route::get('/', [App\Http\Controllers\Admin\DashboardController::class, 'index'])->name('dashboard');
    
    // Rotas de postagens
    Route::resource('postagens', App\Http\Controllers\Admin\PostagemController::class);
    
    // Rotas de serviços
    Route::resource('servicos', App\Http\Controllers\Admin\ServicoController::class);
}); 